==> apo-ws-client-6.00.10.3-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerETP.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="etape" type="{EtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}EtapeDTO" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "etape"
})
@XmlRootElement(name = "creerETP", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier_17102019")
public class CreerETP {

    @XmlElement(required = true)
    protected EtapeDTO etape;

    /**
     * Obtient la valeur de la propriété etape.
     * 
     * @return
     *     possible object is
     *     {@link EtapeDTO }
     *     
     */
    public EtapeDTO getEtape() {
        return etape;
    }

    /**
     * Définit la valeur de la propriété etape.
     * 
     * @param value
     *     allowed object is
     *     {@link EtapeDTO }
     *     
     */
    public void setEtape(EtapeDTO value) {
        this.etape = value;
    }

}

==> apo-ws-client-6.00.50.3-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerETP.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="etape" type="{EtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}EtapeDTO" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "etape"
})
@XmlRootElement(name = "creerETP", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier")
public class CreerETP {

    @XmlElement(required = true)
    protected EtapeDTO etape;

    /**
     * Obtient la valeur de la propriété etape.
     * 
     * @return
     *     possible object is
     *     {@link EtapeDTO }
     *     
     */
    public EtapeDTO getEtape() {
        return etape;
    }

    /**
     * Définit la valeur de la propriété etape.
     * 
     * @param value
     *     allowed object is
     *     {@link EtapeDTO }
     *     
     */
    public void setEtape(EtapeDTO value) {
        this.etape = value;
    }

}
